#[non_exhaustive]pub enum StructuralSetKind {
Show 28 variants
Preface,
Identification,
ContentStorage,
EssenceContainerData,
MaterialPackage,
SourcePackage,
TimelineTrack,
EventTrackDm,
StaticTrackDm,
Sequence,
SourceClip,
TimecodeComponent,
DmSegment,
DmSourceClip,
Filler,
PackageMarkerObject,
FileDescriptor,
GenericPictureEssenceDescriptor,
CdciEssenceDescriptor,
RgbaEssenceDescriptor,
GenericSoundEssenceDescriptor,
GenericDataEssenceDescriptor,
MultipleDescriptor,
NetworkLocator,
TextLocator,
ApplicationPlugInObject,
ApplicationReferencedObject,
Unknown([u8; 2]),
}Expand description
Set Kind (Table 17 — this crate’s byte 14/15 identification list for
every Header Metadata Set the spec defines, whether or not this crate
types its properties). See docs/st377-1.md’s Table 17 reproduction.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Preface
Preface (A.2) — typed, crate::Preface.
Identification
Identification (A.3) — typed, crate::Identification.
ContentStorage
Content Storage (A.4) — typed, crate::ContentStorage.
EssenceContainerData
Essence Container Data (A.5) — typed, crate::EssenceContainerData.
MaterialPackage
Material Package (E.1) — identified only.
SourcePackage
Source Package, File/Physical variants (E.2-E.4) — identified only.
TimelineTrack
Timeline Track, all cases (B.12/B.15/B.18/B.21/B.24/B.27.1) — identified only.
EventTrackDm
Event Track (DM) (B.13/B.27.2) — identified only.
StaticTrackDm
Static Track (DM) (B.14/B.27.3) — identified only.
Sequence
Sequence, all cases (B.9/B.16/B.19/B.22/B.25/B.28) — identified only.
SourceClip
Source Clip, Picture/Sound/Data (B.10/B.20/B.23/B.26) — identified only.
TimecodeComponent
Timecode Component (B.17) — identified only.
DmSegment
DM Segment (B.32) — identified only.
DmSourceClip
DM Source Clip (B.33) — identified only.
Filler
Filler (B.11) — identified only.
PackageMarkerObject
Package Marker Object (B.34) — identified only.
FileDescriptor
File Descriptor (F.2) — identified only.
GenericPictureEssenceDescriptor
Generic Picture Essence Descriptor (F.4.1) — identified only.
CdciEssenceDescriptor
CDCI Essence Descriptor (F.4.2) — identified only.
RgbaEssenceDescriptor
RGBA Essence Descriptor (F.4.3) — identified only.
GenericSoundEssenceDescriptor
Generic Sound Essence Descriptor (F.5) — identified only.
GenericDataEssenceDescriptor
Generic Data Essence Descriptor (F.6) — identified only.
MultipleDescriptor
Multiple Descriptor (F.3) — identified only.
NetworkLocator
Network Locator (B.4) — identified only.
TextLocator
Text Locator (B.5) — identified only.
ApplicationPlugInObject
Application Plug-In Object (C.2) — identified only.
ApplicationReferencedObject
Application Referenced Object (C.3) — identified only.
Unknown([u8; 2])
Any byte 14/15 pair not in Table 17 (private/dark extension, or a Set defined by another SMPTE document, e.g. an Essence Container or Operational Pattern spec — 9.6.1 Note 3).
Implementations